import json

# get working dir
import os
from pathlib import Path

working_dir = Path(os.getcwd())
BLOCKS = json.load(open(os.path.join(working_dir, 'protocols/v765/minecraft-data/blocks.json')))
BLOCK_COLLISION_SHAPES = json.load(
    open(os.path.join(working_dir, 'protocols/v765/minecraft-data/blockCollisionShapes.json')),
)

# TODO: Make it parse dynamically
WATER_BLOCK_ID = 32
WATER_LIKE_BLOCK_IDS = {126, 127, 678, 731}
LAVA_BLOCK_ID = 33
SLIME_BLOCK_ID = 463
COB_WEB_ID = 122
BUBBLE_COLUMN_ID = 731
AIR_BLOCK_ID = 0

BIOMES = json.load(open(os.path.join(working_dir, 'protocols/v765/minecraft-data/biomes.json')))

ENTITIES = {
    0: {
        'name': 'allay',
        'displayName': 'Allay',
        'width': 0.35,
        'height': 0.6,
        'type': 'mob',
        'category': 'Passive mobs',
    },
    1: {
        'name': 'area_effect_cloud',
        'displayName': 'Area Effect Cloud',
        'width': 6,
        'height': 0.5,
        'type': 'other',
        'category': 'UNKNOWN',
    },
    2: {
        'name': 'armor_stand',
        'displayName': 'Armor Stand',
        'width': 0.5,
        'height': 1.975,
        'type': 'living',
        'category': 'Immobile',
    },
    3: {
        'name': 'arrow',
        'displayName': 'Arrow',
        'width': 0.5,
        'height': 0.5,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    4: {
        'name': 'axolotl',
        'displayName': 'Axolotl',
        'width': 0.75,
        'height': 0.42,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    5: {
        'name': 'bat',
        'displayName': 'Bat',
        'width': 0.5,
        'height': 0.9,
        'type': 'ambient',
        'category': 'Passive mobs',
    },
    6: {'name': 'bee', 'displayName': 'Bee', 'width': 0.7, 'height': 0.6, 'type': 'animal', 'category': 'Passive mobs'},
    7: {
        'name': 'blaze',
        'displayName': 'Blaze',
        'width': 0.6,
        'height': 1.8,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    8: {
        'name': 'block_display',
        'displayName': 'Block Display',
        'width': 0,
        'height': 0,
        'type': 'other',
        'category': 'Immobile',
    },
    9: {
        'name': 'boat',
        'displayName': 'Boat',
        'width': 1.375,
        'height': 0.5625,
        'type': 'other',
        'category': 'Vehicles',
    },
    10: {
        'name': 'breeze',
        'displayName': 'Breeze',
        'width': 0.6,
        'height': 1.7,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    11: {
        'name': 'camel',
        'displayName': 'Camel',
        'width': 1.7,
        'height': 2.375,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    12: {
        'name': 'cat',
        'displayName': 'Cat',
        'width': 0.6,
        'height': 0.7,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    13: {
        'name': 'cave_spider',
        'displayName': 'Cave Spider',
        'width': 0.7,
        'height': 0.5,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    14: {
        'name': 'chest_boat',
        'displayName': 'Boat with Chest',
        'width': 1.375,
        'height': 0.5625,
        'type': 'other',
        'category': 'Vehicles',
    },
    15: {
        'name': 'chest_minecart',
        'displayName': 'Minecart with Chest',
        'width': 0.98,
        'height': 0.7,
        'type': 'other',
        'category': 'Vehicles',
    },
    16: {
        'name': 'chicken',
        'displayName': 'Chicken',
        'width': 0.4,
        'height': 0.7,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    17: {
        'name': 'cod',
        'displayName': 'Cod',
        'width': 0.5,
        'height': 0.3,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    18: {
        'name': 'command_block_minecart',
        'displayName': 'Minecart with Command Block',
        'width': 0.98,
        'height': 0.7,
        'type': 'other',
        'category': 'Vehicles',
    },
    19: {
        'name': 'cow',
        'displayName': 'Cow',
        'width': 0.9,
        'height': 1.4,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    20: {
        'name': 'creeper',
        'displayName': 'Creeper',
        'width': 0.6,
        'height': 1.7,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    21: {
        'name': 'dolphin',
        'displayName': 'Dolphin',
        'width': 0.9,
        'height': 0.6,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    22: {
        'name': 'donkey',
        'displayName': 'Donkey',
        'width': 1.3964844,
        'height': 1.5,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    23: {
        'name': 'dragon_fireball',
        'displayName': 'Dragon Fireball',
        'width': 1,
        'height': 1,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    24: {
        'name': 'drowned',
        'displayName': 'Drowned',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    25: {
        'name': 'egg',
        'displayName': 'Thrown Egg',
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    26: {
        'name': 'elder_guardian',
        'displayName': 'Elder Guardian',
        'width': 1.9975,
        'height': 1.9975,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    27: {
        'name': 'end_crystal',
        'displayName': 'End Crystal',
        'width': 2,
        'height': 2,
        'type': 'other',
        'category': 'Immobile',
    },
    28: {
        'name': 'ender_dragon',
        'displayName': 'Ender Dragon',
        'width': 16,
        'height': 8,
        'type': 'mob',
        'category': 'Hostile mobs',
    },
    29: {
        'name': 'ender_pearl',
        'displayName': 'Thrown Ender Pearl',
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    30: {
        'name': 'enderman',
        'displayName': 'Enderman',
        'width': 0.6,
        'height': 2.9,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    31: {
        'name': 'endermite',
        'displayName': 'Endermite',
        'width': 0.4,
        'height': 0.3,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    32: {
        'name': 'evoker',
        'displayName': 'Evoker',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    33: {
        'name': 'evoker_fangs',
        'displayName': 'Evoker Fangs',
        'width': 0.5,
        'height': 0.8,
        'type': 'other',
        'category': 'Hostile mobs',
    },
    34: {
        'name': 'experience_bottle',
        'displayName': "Thrown Bottle o' Enchanting",
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    35: {
        'name': 'experience_orb',
        'displayName': 'Experience Orb',
        'width': 0.5,
        'height': 0.5,
        'type': 'other',
        'category': 'UNKNOWN',
    },
    36: {
        'name': 'eye_of_ender',
        'displayName': 'Eye of Ender',
        'width': 0.25,
        'height': 0.25,
        'type': 'other',
        'category': 'UNKNOWN',
    },
    37: {
        'name': 'falling_block',
        'displayName': 'Falling Block',
        'width': 0.98,
        'height': 0.98,
        'type': 'other',
        'category': 'UNKNOWN',
    },
    38: {
        'name': 'firework_rocket',
        'displayName': 'Firework Rocket',
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    39: {
        'name': 'fox',
        'displayName': 'Fox',
        'width': 0.6,
        'height': 0.7,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    40: {
        'name': 'frog',
        'displayName': 'Frog',
        'width': 0.5,
        'height': 0.5,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    41: {
        'name': 'furnace_minecart',
        'displayName': 'Minecart with Furnace',
        'width': 0.98,
        'height': 0.7,
        'type': 'other',
        'category': 'Vehicles',
    },
    42: {'name': 'ghast', 'displayName': 'Ghast', 'width': 4, 'height': 4, 'type': 'mob', 'category': 'Hostile mobs'},
    43: {
        'name': 'giant',
        'displayName': 'Giant',
        'width': 3.6,
        'height': 12,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    44: {
        'name': 'glow_item_frame',
        'displayName': 'Glow Item Frame',
        'width': 0.5,
        'height': 0.5,
        'type': 'other',
        'category': 'Immobile',
    },
    45: {
        'name': 'glow_squid',
        'displayName': 'Glow Squid',
        'width': 0.8,
        'height': 0.8,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    46: {
        'name': 'goat',
        'displayName': 'Goat',
        'width': 0.9,
        'height': 1.3,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    47: {
        'name': 'guardian',
        'displayName': 'Guardian',
        'width': 0.85,
        'height': 0.85,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    48: {
        'name': 'hoglin',
        'displayName': 'Hoglin',
        'width': 1.3964844,
        'height': 1.4,
        'type': 'animal',
        'category': 'Hostile mobs',
    },
    49: {
        'name': 'hopper_minecart',
        'displayName': 'Minecart with Hopper',
        'width': 0.98,
        'height': 0.7,
        'type': 'other',
        'category': 'Vehicles',
    },
    50: {
        'name': 'horse',
        'displayName': 'Horse',
        'width': 1.3964844,
        'height': 1.6,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    51: {
        'name': 'husk',
        'displayName': 'Husk',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    52: {
        'name': 'illusioner',
        'displayName': 'Illusioner',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    53: {
        'name': 'interaction',
        'displayName': 'Interaction',
        'width': 0,
        'height': 0,
        'type': 'other',
        'category': 'Immobile',
    },
    54: {
        'name': 'iron_golem',
        'displayName': 'Iron Golem',
        'width': 1.4,
        'height': 2.7,
        'type': 'mob',
        'category': 'Passive mobs',
    },
    55: {'name': 'item', 'displayName': 'Item', 'width': 0.25, 'height': 0.25, 'type': 'other', 'category': 'UNKNOWN'},
    56: {
        'name': 'item_display',
        'displayName': 'Item Display',
        'width': 0,
        'height': 0,
        'type': 'other',
        'category': 'Immobile',
    },
    57: {
        'name': 'item_frame',
        'displayName': 'Item Frame',
        'width': 0.5,
        'height': 0.5,
        'type': 'other',
        'category': 'Immobile',
    },
    58: {
        'name': 'fireball',
        'displayName': 'Fireball',
        'width': 1,
        'height': 1,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    59: {
        'name': 'leash_knot',
        'displayName': 'Leash Knot',
        'width': 0.375,
        'height': 0.5,
        'type': 'other',
        'category': 'Immobile',
    },
    60: {
        'name': 'lightning_bolt',
        'displayName': 'Lightning Bolt',
        'width': 0,
        'height': 0,
        'type': 'other',
        'category': 'UNKNOWN',
    },
    61: {
        'name': 'llama',
        'displayName': 'Llama',
        'width': 0.9,
        'height': 1.87,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    62: {
        'name': 'llama_spit',
        'displayName': 'Llama Spit',
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    63: {
        'name': 'magma_cube',
        'displayName': 'Magma Cube',
        'width': 2.04,
        'height': 2.04,
        'type': 'mob',
        'category': 'Hostile mobs',
    },
    64: {'name': 'marker', 'displayName': 'Marker', 'width': 0, 'height': 0, 'type': 'other', 'category': 'UNKNOWN'},
    65: {
        'name': 'minecart',
        'displayName': 'Minecart',
        'width': 0.98,
        'height': 0.7,
        'type': 'other',
        'category': 'Vehicles',
    },
    66: {
        'name': 'mooshroom',
        'displayName': 'Mooshroom',
        'width': 0.9,
        'height': 1.4,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    67: {
        'name': 'mule',
        'displayName': 'Mule',
        'width': 1.3964844,
        'height': 1.6,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    68: {
        'name': 'ocelot',
        'displayName': 'Ocelot',
        'width': 0.6,
        'height': 0.7,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    69: {
        'name': 'painting',
        'displayName': 'Painting',
        'width': 0.5,
        'height': 0.5,
        'type': 'other',
        'category': 'Immobile',
    },
    70: {
        'name': 'panda',
        'displayName': 'Panda',
        'width': 1.3,
        'height': 1.25,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    71: {
        'name': 'parrot',
        'displayName': 'Parrot',
        'width': 0.5,
        'height': 0.9,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    72: {
        'name': 'phantom',
        'displayName': 'Phantom',
        'width': 0.9,
        'height': 0.5,
        'type': 'mob',
        'category': 'Hostile mobs',
    },
    73: {
        'name': 'pig',
        'displayName': 'Pig',
        'width': 0.9,
        'height': 0.9,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    74: {
        'name': 'piglin',
        'displayName': 'Piglin',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    75: {
        'name': 'piglin_brute',
        'displayName': 'Piglin Brute',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    76: {
        'name': 'pillager',
        'displayName': 'Pillager',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    77: {
        'name': 'polar_bear',
        'displayName': 'Polar Bear',
        'width': 1.4,
        'height': 1.4,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    78: {
        'name': 'potion',
        'displayName': 'Potion',
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    79: {
        'name': 'pufferfish',
        'displayName': 'Pufferfish',
        'width': 0.7,
        'height': 0.7,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    80: {
        'name': 'rabbit',
        'displayName': 'Rabbit',
        'width': 0.4,
        'height': 0.5,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    81: {
        'name': 'ravager',
        'displayName': 'Ravager',
        'width': 1.95,
        'height': 2.2,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    82: {
        'name': 'salmon',
        'displayName': 'Salmon',
        'width': 0.7,
        'height': 0.4,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    83: {
        'name': 'sheep',
        'displayName': 'Sheep',
        'width': 0.9,
        'height': 1.3,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    84: {
        'name': 'shulker',
        'displayName': 'Shulker',
        'width': 1,
        'height': 1,
        'type': 'mob',
        'category': 'Hostile mobs',
    },
    85: {
        'name': 'shulker_bullet',
        'displayName': 'Shulker Bullet',
        'width': 0.3125,
        'height': 0.3125,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    86: {
        'name': 'silverfish',
        'displayName': 'Silverfish',
        'width': 0.4,
        'height': 0.3,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    87: {
        'name': 'skeleton',
        'displayName': 'Skeleton',
        'width': 0.6,
        'height': 1.99,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    88: {
        'name': 'skeleton_horse',
        'displayName': 'Skeleton Horse',
        'width': 1.3964844,
        'height': 1.6,
        'type': 'animal',
        'category': 'Hostile mobs',
    },
    89: {
        'name': 'slime',
        'displayName': 'Slime',
        'width': 2.04,
        'height': 2.04,
        'type': 'mob',
        'category': 'Hostile mobs',
    },
    90: {
        'name': 'small_fireball',
        'displayName': 'Small Fireball',
        'width': 0.3125,
        'height': 0.3125,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    91: {
        'name': 'sniffer',
        'displayName': 'Sniffer',
        'width': 1.9,
        'height': 1.75,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    92: {
        'name': 'snow_golem',
        'displayName': 'Snow Golem',
        'width': 0.7,
        'height': 1.9,
        'type': 'mob',
        'category': 'Passive mobs',
    },
    93: {
        'name': 'snowball',
        'displayName': 'Snowball',
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    94: {
        'name': 'spawner_minecart',
        'displayName': 'Minecart with Monster Spawner',
        'width': 0.98,
        'height': 0.7,
        'type': 'other',
        'category': 'Vehicles',
    },
    95: {
        'name': 'spectral_arrow',
        'displayName': 'Spectral Arrow',
        'width': 0.5,
        'height': 0.5,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    96: {
        'name': 'spider',
        'displayName': 'Spider',
        'width': 1.4,
        'height': 0.9,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    97: {
        'name': 'squid',
        'displayName': 'Squid',
        'width': 0.8,
        'height': 0.8,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    98: {
        'name': 'stray',
        'displayName': 'Stray',
        'width': 0.6,
        'height': 1.99,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    99: {
        'name': 'strider',
        'displayName': 'Strider',
        'width': 0.9,
        'height': 1.7,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    100: {
        'name': 'tadpole',
        'displayName': 'Tadpole',
        'width': 0.4,
        'height': 0.3,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    101: {
        'name': 'text_display',
        'displayName': 'Text Display',
        'width': 0,
        'height': 0,
        'type': 'other',
        'category': 'Immobile',
    },
    102: {
        'name': 'tnt',
        'displayName': 'Primed TNT',
        'width': 0.98,
        'height': 0.98,
        'type': 'other',
        'category': 'UNKNOWN',
    },
    103: {
        'name': 'tnt_minecart',
        'displayName': 'Minecart with TNT',
        'width': 0.98,
        'height': 0.7,
        'type': 'other',
        'category': 'Vehicles',
    },
    104: {
        'name': 'trader_llama',
        'displayName': 'Trader Llama',
        'width': 0.9,
        'height': 1.87,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    105: {
        'name': 'trident',
        'displayName': 'Trident',
        'width': 0.5,
        'height': 0.5,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    106: {
        'name': 'tropical_fish',
        'displayName': 'Tropical Fish',
        'width': 0.5,
        'height': 0.4,
        'type': 'water_creature',
        'category': 'Passive mobs',
    },
    107: {
        'name': 'turtle',
        'displayName': 'Turtle',
        'width': 1.2,
        'height': 0.4,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    108: {
        'name': 'vex',
        'displayName': 'Vex',
        'width': 0.4,
        'height': 0.8,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    109: {
        'name': 'villager',
        'displayName': 'Villager',
        'width': 0.6,
        'height': 1.95,
        'type': 'passive',
        'category': 'Passive mobs',
    },
    110: {
        'name': 'vindicator',
        'displayName': 'Vindicator',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    111: {
        'name': 'wandering_trader',
        'displayName': 'Wandering Trader',
        'width': 0.6,
        'height': 1.95,
        'type': 'passive',
        'category': 'Passive mobs',
    },
    112: {
        'name': 'warden',
        'displayName': 'Warden',
        'width': 0.9,
        'height': 2.9,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    113: {
        'name': 'wind_charge',
        'displayName': 'Wind Charge',
        'width': 0.3125,
        'height': 0.3125,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    114: {
        'name': 'witch',
        'displayName': 'Witch',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    115: {
        'name': 'wither',
        'displayName': 'Wither',
        'width': 0.9,
        'height': 3.5,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    116: {
        'name': 'wither_skeleton',
        'displayName': 'Wither Skeleton',
        'width': 0.7,
        'height': 2.4,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    117: {
        'name': 'wither_skull',
        'displayName': 'Wither Skull',
        'width': 0.3125,
        'height': 0.3125,
        'type': 'projectile',
        'category': 'Projectiles',
    },
    118: {
        'name': 'wolf',
        'displayName': 'Wolf',
        'width': 0.6,
        'height': 0.85,
        'type': 'animal',
        'category': 'Passive mobs',
    },
    119: {
        'name': 'zoglin',
        'displayName': 'Zoglin',
        'width': 1.3964844,
        'height': 1.4,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    120: {
        'name': 'zombie',
        'displayName': 'Zombie',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    121: {
        'name': 'zombie_horse',
        'displayName': 'Zombie Horse',
        'width': 1.3964844,
        'height': 1.6,
        'type': 'animal',
        'category': 'Hostile mobs',
    },
    122: {
        'name': 'zombie_villager',
        'displayName': 'Zombie Villager',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    123: {
        'name': 'zombified_piglin',
        'displayName': 'Zombified Piglin',
        'width': 0.6,
        'height': 1.95,
        'type': 'hostile',
        'category': 'Hostile mobs',
    },
    124: {
        'name': 'player',
        'displayName': 'Player',
        'width': 0.6,
        'height': 1.8,
        'type': 'player',
        'category': 'UNKNOWN',
    },
    125: {
        'name': 'fishing_bobber',
        'displayName': 'Fishing Bobber',
        'width': 0.25,
        'height': 0.25,
        'type': 'projectile',
        'category': 'Projectiles',
    },
}
DIMENSIONS = {
    "overworld": {
        "name": "overworld",
        "minY": -64,
        "height": 384,
    },
    "overworld_caves": {
        "name": "overworld_caves",
        "minY": -64,
        "height": 384,
    },
    "the_end": {
        "name": "the_end",
        "minY": 0,
        "height": 256,
    },
    "the_nether": {
        "name": "the_nether",
        "minY": 0,
        "height": 256,
    },
}
